.. twstock documentation master file, created by
   sphinx-quickstart on Mon Jul 24 14:17:35 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

歡迎來到 twstock 文件系統!
==========================

===============================
twstock - 台灣股市股票價格擷取
===============================

`twstock` 是一個簡潔好用的台灣股市程式，透過 twstock，您可以簡單的查詢
各類股票之資訊以及即時的股票狀況。

twstock 設計僅支援 Python 3 以上之版本，目前最新版 Python 3.6.2 效能
已有 Python 2.7 之能力，甚有超過之指標，作者在這邊也鼓勵使用者轉向使用 Python 3。


使用上有問題可以透過 `issues <https://github.com/mlouielu/twstock/issues>`_ 或是
`twstock gitter.im <https://gitter.im/twstock/Lobby>`_ 詢問。


使用指南 - User's Guide
-------------------------

.. toctree::
   prepare.rst
   quickstart.rst



API 參照索引 - API Reference
------------------------------

如果你正在尋找某個特定指令、class 或 method 的介紹，請參照
這部份的文件。

.. toctree::
   reference/index.rst


額外資訊 - Additional Notes
-----------------------------

.. toctree::
   contributing.rst
   license.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
